Module: Ramco::API::Entities
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/entities.rb
Instance Method Summary collapse
-
#get_entities(params = {}) ⇒ Object
Get entities Fetch the attributes and/or relationships of multiple entities of one type using a user-defined filter.
Instance Method Details
#get_entities(params = {}) ⇒ Object
Get entities Fetch the attributes and/or relationships of multiple entities of one type using a user-defined filter.
Entity = Name of entity being queried (ex: Contact) Filter (optional) = User-specified filter string Attributes = comma separated list of attributes to return StringDelimiter (optional) = User-specified delimiter used to wrap string values (default is #) MaxResults (optional) = Maximum number of entities to return
=> “Contact”, “attributes” => “ContactId,FirstName,LastName”, “maxresults” => “5”
Returns json
18 19 20 21 |
# File 'lib/ramco/api/entities.rb', line 18 def get_entities(params={}) params['operation'] = "GetEntities" request(connection, params) end |