Module: Ramco::API::EntityMetadata
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/entity_metadata.rb
Instance Method Summary collapse
-
#get_entity_metadata(params = {}) ⇒ Object
GetEntityMetadata Fetch metadata on entity type, including entity description, attributes and relationships Entity = Name of entity being queried, for example: Contact.
Instance Method Details
#get_entity_metadata(params = {}) ⇒ Object
GetEntityMetadata Fetch metadata on entity type, including entity description, attributes and relationships Entity = Name of entity being queried, for example: Contact
=> “Contact”
Returns json
13 14 15 16 |
# File 'lib/ramco/api/entity_metadata.rb', line 13 def (params={}) params['operation'] = "GetEntityMetadata" request(connection, params) end |