Module: Ramco::API::EntityTypes
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/entity_types.rb
Instance Method Summary collapse
-
#get_entity_types(params = {}) ⇒ Object
GetEntityTypes Returns a complete list of all entities in the system.
Instance Method Details
#get_entity_types(params = {}) ⇒ Object
GetEntityTypes Returns a complete list of all entities in the system
Returns json
10 11 12 13 |
# File 'lib/ramco/api/entity_types.rb', line 10 def get_entity_types(params={}) params['operation'] = "GetEntityTypes" request(connection, params) end |