Module: Ramco::API::ValidateUser
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/validate_user.rb
Instance Method Summary collapse
-
#validate_user(params = {}) ⇒ Object
ValidateUser Returns the globally unique id of a contact that matches the provided cobalt_username and cobalt_password parameters.
Instance Method Details
#validate_user(params = {}) ⇒ Object
ValidateUser Returns the globally unique id of a contact that matches the provided cobalt_username and cobalt_password parameters.
Returns a 422 error when there is no user with provided username/password combination.
cobalt_username = User’s username cobalt_password = User’s password
=> “username”, “cobalt_password” => “password”
Returns json
18 19 20 21 |
# File 'lib/ramco/api/validate_user.rb', line 18 def validate_user(params={}) params['operation'] = "ValidateUser" request(connection, params) end |