Module: Ramco::API::ClearCache
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/clear_cache.rb
Instance Method Summary collapse
-
#clear_cache(params = {}) ⇒ Object
ClearCache Clears the server-side metadata cache.
Instance Method Details
#clear_cache(params = {}) ⇒ Object
ClearCache Clears the server-side metadata cache. If an entity or attribute has been added (or removed), then clearing the cache will permit the changes to be reflected immediately. The cache will normally expire every 24 hours.
Returns json
12 13 14 15 |
# File 'lib/ramco/api/clear_cache.rb', line 12 def clear_cache(params={}) params['operation'] = "ClearCache" request(connection, params) end |