Module: Ramco::API::Entity
- Included in:
- Ramco
- Defined in:
- lib/ramco/api/entity.rb
Instance Method Summary collapse
-
#create_entity(params = {}) ⇒ Object
CreateEntity Allows for creation of a new entity record.
-
#get_entity(params = {}) ⇒ Object
GetEntity Fetch the attributes and/or relationships of one specific entity using guid.
-
#update_entity(params = {}) ⇒ Object
UpdateEntity Allows for modification of attributes of existing Entities.
Instance Method Details
#create_entity(params = {}) ⇒ Object
CreateEntity Allows for creation of a new entity record.
Entity = Type of entity being modified (ex: Contact) AttributeValues = Comma separated attribute=value pairs. StringDelimiter (optional) = User-specified delimiter used to wrap string values (default is #)
=> “Contact”, “attribute_values” => “FirstName=#Jane#,Birthday=1980-12-31,EmailVerified=true,NumChildren=3”
Returns json
32 33 34 35 |
# File 'lib/ramco/api/entity.rb', line 32 def create_entity(params={}) params['operation'] = "CreateEntity" request(connection, params) end |
#get_entity(params = {}) ⇒ Object
GetEntity Fetch the attributes and/or relationships of one specific entity using guid.
Entity = Type of entity being queried (ex: Contact) Guid = guid of entity to return Attributes = comma separated list of attributes to return
=> “Contact”, “guid” => “6868642f-0144-e811-9c17-00155d10120d”, “attributes” => “ContactId,FirstName,LastName”
Returns json
16 17 18 19 |
# File 'lib/ramco/api/entity.rb', line 16 def get_entity(params={}) params['operation'] = "GetEntity" request(connection, params) end |
#update_entity(params = {}) ⇒ Object
UpdateEntity Allows for modification of attributes of existing Entities.
Entity = Type of entity being modified (ex: Contact) Guid = guid of entity being modified AttributeValues = Comma separated attribute=value pairs. StringDelimiter (optional) = User-specified delimiter used to wrap string values (default is #)
=> “Contact”, “attribute_values” => “FirstName=#Jane#,Birthday=1980-12-31,EmailVerified=true,NumChildren=3”
Returns json
49 50 51 52 |
# File 'lib/ramco/api/entity.rb', line 49 def update_entity(params={}) params['operation'] = "UpdateEntity" request(connection, params) end |